==> maxdb-all-linux-64bit-x86_64-7_6_00_36.tgz: SAPDB/Install/Frame/StartSetup.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_00/b_36/sys/src/install/perl/SAPDB/Install/Frame/StartSetup.pm#1 $
# $DateTime: 2006/11/17 17:24:42 $
# $Change: 140017 $
#
# Desc: start SAP DB installation/update/patch/instanceupgrade, called by SDBINST/SDBUPD

package SAPDB::Install::Frame::StartSetup;

use Wx::Event qw (EVT_SIZE EVT_COMMAND_ENTER EVT_SET_FOCUS);
use Wx qw (wxDefaultSize
		   wxEVT_COMMAND_ENTER wxICON_ERROR
		   wxCENTRE wxICON_INFORMATION wxVERTICAL
		   wxEXPAND);

use SAPDB::Install::Frame::Base;
use SAPDB::Install::Window::Banner;
use SAPDB::Install::Window::Browser;
use SAPDB::Install::Window::Wizard;
use SAPDB::Install::Wizard::Dialog::Collector;
use SAPDB::Install::Wizard::Dialog::Components;
use SAPDB::Install::Wizard::Dialog::Finalize;
use SAPDB::Install::Wizard::Dialog::Install;		
use SAPDB::Install::Wizard::Dialog::Prepare;
use SAPDB::Install::Wizard::Dialog::SoftwareParameter;
use SAPDB::Install::Wizard::Dialog::Summary;
use SAPDB::Install::Trace;
use SAPDB::Install::Tools;
use SAPDB::Install::Registry;
use SAPDB::Install::System;

our @ISA = qw (SAPDB::Install::Frame::Base);

sub new {
 	my( $class ) = shift;
	my ($indep_data,$indep_prog) = readIndepPath();
	my( $this ) = $class->SUPER::new(@_);
	my $sizer = Wx::BoxSizer->new(wxVERTICAL);
	my $rc = SAPDB::Install::Resources->new('RESOURCES.TGZ');
	$rc->readAll;
	$this->{'banner'} = SAPDB::Install::Window::Banner->new($this,-1,[0,0],[20,80]);
	$this->{'banner'}->setTitle("Installation Manager");
	$this->{'banner'}->setSubTitle(" ");
	$this->{'banner'}->Fit;
	$sizer->Add($this->{'banner'},0,wxEXPAND);
	$this->{'browser'} = SAPDB::Install::Window::Browser->new($this,-1,[0,0],[-1,-1]);
	#$this->SetNextHandler($this->{'browser'});
	$this->{'browser'}->initDesk([
		[
			"Start installation/\nupgrade",
			'icon/package.png',
			"Install MaxDB software \nand optionally create\nor upgrade a database\ninstance",
			sub {
				unless(IsAdmin()){
					my $msgbox = Wx::MessageDialog->new($this,
									$^O =~ /mswin/i ? 
									'Please start installation as local administrator!' :
									'Please restart as user root!',
									"No Privileges", wxICON_ERROR | wxCENTRE);
					$msgbox->ShowModal();
					return;
						$msgbox->Destroy();
				}
				
				my $license_file = $SAPDB::Install::Config{'RuntimeDir'}.'/LICENSE';				
				
				if (-f $license_file){
					require SAPDB::Install::Dialog::AcceptLicense;
				
					my $dlg = SAPDB::Install::Dialog::AcceptLicense->new ($this,-1);
					
					unless ($dlg->ShowModal () == 0){
						$dlg->Destroy ();
						return undef;
					}
					$dlg->Destroy ();
				}
				$this->AddPendingEvent(Wx::CommandEvent->new(wxEVT_COMMAND_ENTER,98765))
			}
		],
		[
			"Show MaxDB\ncomponents",
			'icon/viewer.png',
			"Show existing\nMaxDB components\nand databases",
			sub {
				if($indep_data =~ /\S/ and -d "$indep_data/config/install"){
					require SAPDB::Install::Dialog::InstallationView;
					my $dlg = SAPDB::Install::Dialog::InstallationView->new($self,-1);
					$dlg->Destroy;
				}
				else{
					my $msgbox =  Wx::MessageDialog->new($self,'No installed MaxDB components found!',
					'Installation Viewer', wxICON_INFORMATION | wxCENTRE);
					$msgbox->ShowModal();
					$msgbox->Destroy;
				}
			}
		],
		[
			"Remove MaxDB\ncomponents",
			'icon/uninstall.png',
			"Uninstall already\ninstalled MaxDB\nsoftware and remove\nexisting databases",
			sub {
				
				unless(IsAdmin()){
					my $msgbox = Wx::MessageDialog->new($this,
									$^O =~ /mswin/i ? 
									'Please start installation as local administrator!' :
									'Please restart as user root!',
														"No Privileges", wxICON_ERROR | wxCENTRE);
					$msgbox->ShowModal();
					return;
				}
				
				if($indep_data =~ /\S/ and -d "$indep_data/config/install"){
					require SAPDB::Install::Dialog::Uninstall;
					my $dlg = SAPDB::Install::Dialog::Uninstall->new($self,-1);
					$dlg->ShowModal;
					$dlg->Destroy;
					#
					#	reset cleaner
					#
					my $level = 0;
					while(1){
						my @all_info_caller_package = (caller($level));
						$#all_info_caller_package == -1  and last;
						$level++;
						my $package = $all_info_caller_package[0];
						if(defined ${"${package}::cleaner"} and	ref(${"${package}::cleaner"}) eq 'SAPDB::Install::Cleaner'){ 
							TraceMsg("found cleaner object \$${package}::cleaner\n",3,\$DEBUG);
							${"${package}::cleaner"}->DESTROY;
							last;
						}	
					}
				}
				else{
					my $msgbox =  Wx::MessageDialog->new($self,'No installed MaxDB components found!',
					'Installation Viewer', wxICON_INFORMATION | wxCENTRE);
					$msgbox->ShowModal();
					$msgbox->Destroy;
				}
			}
		],
		[
			"Visit MaxDB\nwebsite",
			'icon/globe.png',
			"Show MaxDB\nhomepage",
			sub {
				if($^O =~ /mswin/i){
					my $home_dir = $ENV{'HOMEDRIVE'}.$ENV{'HOMEPATH'};
					my $cwd;
					if(-d $home_dir){
						require SAPDB::Install::Cwd;
						$cwd = SAPDB::Install::Cwd::getcwd();	
						chdir($home_dir);
					}
					system("rundll32 url.dll,FileProtocolHandler http://www.mysql.com/maxdb");
					if($cwd =~ /\S/){
						chdir($cwd);
					}
				}
				else{
					my $browser = getBrowser();
					unless($browser =~ /\S/){
						my $msgbox =  Wx::MessageDialog->new($self,'Cannot detect a html browser',
						'Browser missing', wxICON_ERROR | wxCENTRE);
						$msgbox->ShowModal();
						$msgbox->Destroy;
						return undef;
					}
					system("$browser http://www.mysql.com/maxdb &");
				}			
			}
		]
	]);
	EVT_COMMAND_ENTER($this,98765,\&StartWizard);
	$this->{'browser'}->FindWindow($this->{'browser'}->{'links'}->[0])->select; 
	$sizer->Add($this->{'browser'},1,wxEXPAND);
	$this->SetSizerAndFit($sizer);
	$this->SetAutoLayout(1);
	
	#
	# use 3:2 ratio if possible
	#
	
	my ($w,$h) = $this->GetSizeWH;
	my $new_h = int($w * 2 / 3);
	if ($new_h > $h){
		$this->SetSize($w,$new_h);
	}
	
	$this->{'browser'}->SetFocus;
	$this;
}

sub StartWizard{
	my ($self,$evt) = @_;
	Wx::Yield();
	$self->GetSizer->Remove($self->{'browser'});
	$self->{'browser'}->Destroy;
	$self->{'browser'} = undef;
	delete $self->{'browser'};
	$self->{'wizard'} = SAPDB::Install::Window::Wizard->new($self,-1,[0,80],wxDefaultSize);
	
	
	if($SAPDB::Install::Config{'UsedSDBRUN'} eq 'installed'){
			require SAPDB::Install::Wizard::Dialog::ArchiveDir;
			$self->{'wizard'}->AddStep({'name' => 'Select MaxDB software package folder',
										'dlg' => SAPDB::Install::Wizard::Dialog::ArchiveDir->new($self->{'wizard'},
												-1,[0,0],wxDefaultSize)}
							);
	}
		
	$self->{'wizard'}->AddStep({'name' => 'Select component group to be installed',
								'dlg' => SAPDB::Install::Wizard::Dialog::Components->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	$self->{'wizard'}->AddStep({'name' => 'Checking installed software, please wait',
								'dlg' => SAPDB::Install::Wizard::Dialog::SoftwareParameter->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	$self->{'wizard'}->AddStep({'name' => 'Summary of installation settings',
								'dlg' => SAPDB::Install::Wizard::Dialog::Summary->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	
	$self->{'wizard'}->AddStep({'name' => 'Prepare software',
								'dlg' => SAPDB::Install::Wizard::Dialog::Prepare->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	$self->{'wizard'}->AddStep({'name' => 'Software installation',
								'dlg' => SAPDB::Install::Wizard::Dialog::Install->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	$self->{'wizard'}->AddStep({'name' => 'Finished',
								'dlg' => SAPDB::Install::Wizard::Dialog::Finalize->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
								);
	
	$self->GetSizer->Add($self->{'wizard'},1,wxEXPAND);
	$self->{'wizard'}->init;
	$self->{'wizard'}->SetFocus();
}


sub GetBestSize{
	my ($self) = @_;
	my ($width,$height) = (0,0);
	my $banner_size = $self->{'banner'}->GetBestSize;
	$height += $banner_size->GetHeight;
	$width = $banner_size->GetWidth;
	#print ">>>> banner size = ($width,$height)\n"; 
	
	if(defined $self->{'browser'}){
		my $browser_size = $self->{'browser'}->GetBestSize;
		$height += $browser_size->GetHeight;
		$width = $browser_size->GetWidth
			if $browser_size->GetWidth > $width;
	}
	elsif(defined $self->{'wizard'}){
		my $wizard_size = $self->{'wizard'}->GetBestSize;
		#print ">>>> wizard size (".$wizard_size->GetWidth.','.$wizard_size->GetHeight.")\n";
		$height += $wizard_size->GetHeight;
		$width = $wizard_size->GetWidth
			if $wizard_size->GetWidth > $width;
		$self->GetSizer->SetItemMinSize($self->{'wizard'},$wizard_size->GetWidth,$wizard_size->GetHeight);
	}
	return Wx::Size->new($width,$height);
}


sub RecalcBestSize{
	my ($self) = @_;
	$self->GetSizer->RecalcSizes;
	my $size = $self->GetBestSize;
	my ($width,$height) = ($size->GetWidth,$size->GetHeight);
	#print ">>>>> frame best size ($width,$height)\n";
	
	$self->SetSizeHints($width,$height); 
	my ($cur_width,$cur_height) = $self->GetSizeWH;
	my $dirty = 0;
	if($cur_width < $width){
		$cur_width = $width;
		$dirty = 1;	
	}
	if($cur_height < $height){
		$cur_height = $height;
		$dirty = 1;	
	}
	if($dirty){
		$self->SetSize([$cur_width,$cur_height]);
		$self->Layout;
	}
	$self->Layout;
	#print ">>>> frame real size (".join(',',$self->GetSizeWH).")\n";	
	
}


sub Destroy{
	my ($self) = @_;
	while($self->GetSizer->Remove(0)){}
	$self->{'banner'}->Destroy if defined $self->{'banner'};
	delete $self->{'banner'};
	$self->{'wizard'}->Destroy if defined $self->{'wizard'};
	delete $self->{'wizard'};
	$self->{'browser'}->Destroy if defined $self->{'browser'}; 
	delete $self->{'browser'};
	$self->SUPER::Destroy;
}


sub DESTROY{
	my ($self) = @_;
	print ">>>>>> DESTROYING $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;
}

1;

==> maxdb-all-linux-64bit-x86_64-7_6_03_15.tgz: SAPDB/Install/Frame/StartSetup.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_03/b_15/sys/src/install/perl/SAPDB/Install/Frame/StartSetup.pm#1 $
# $DateTime: 2008/01/18 16:05:39 $
# $Change: 173096 $
#
# Desc: start SAP DB installation/update/patch/instanceupgrade, called by SDBINST/SDBUPD

package SAPDB::Install::Frame::StartSetup;

use Wx::Event qw (EVT_SIZE EVT_COMMAND_ENTER EVT_SET_FOCUS);
use Wx qw (wxDefaultSize
		   wxEVT_COMMAND_ENTER wxICON_ERROR
		   wxCENTRE wxICON_INFORMATION wxVERTICAL
		   wxEXPAND);

use SAPDB::Install::Frame::Base;
use SAPDB::Install::Window::Banner;
use SAPDB::Install::Window::Browser;
use SAPDB::Install::Window::Wizard;
use SAPDB::Install::Wizard::Dialog::Collector;
use SAPDB::Install::Wizard::Dialog::Components;
use SAPDB::Install::Wizard::Dialog::Finalize;
use SAPDB::Install::Wizard::Dialog::Install;		
use SAPDB::Install::Wizard::Dialog::Prepare;
use SAPDB::Install::Wizard::Dialog::SoftwareParameter;
use SAPDB::Install::Wizard::Dialog::Summary;
use SAPDB::Install::Trace;
use SAPDB::Install::Tools;
use SAPDB::Install::Registry;
use SAPDB::Install::System;

our @ISA = qw (SAPDB::Install::Frame::Base);

sub new {
 	my( $class ) = shift;
	my ($indep_data,$indep_prog) = readIndepPath();
	my( $this ) = $class->SUPER::new(@_);
	my $sizer = Wx::BoxSizer->new(wxVERTICAL);
	my $rc = SAPDB::Install::Resources->new('RESOURCES.TGZ');
	$rc->readAll;
	$this->{'banner'} = SAPDB::Install::Window::Banner->new($this,-1,[0,0],[20,80]);
	$this->{'banner'}->setTitle("Installation Manager");
	$this->{'banner'}->setSubTitle(" ");
	$this->{'banner'}->Fit;
	$sizer->Add($this->{'banner'},0,wxEXPAND);
	$this->{'browser'} = SAPDB::Install::Window::Browser->new($this,-1,[0,0],[-1,-1]);
	#$this->SetNextHandler($this->{'browser'});
	$this->{'browser'}->initDesk([
		[
			"Start installation/\nupgrade",
			'icon/package.png',
			"Install MaxDB software \nand optionally create\nor upgrade a database\ninstance",
			sub {
				unless(IsAdmin()){
					my $msgbox = Wx::MessageDialog->new($this,
									$^O =~ /mswin/i ? 
									'Please start installation as local administrator!' :
									'Please restart as user root!',
									"No Privileges", wxICON_ERROR | wxCENTRE);
					$msgbox->ShowModal();
					return;
						$msgbox->Destroy();
				}
				
				my $license_file = $SAPDB::Install::Config{'RuntimeDir'}.'/LICENSE';				
				
				if (-f $license_file){
					require SAPDB::Install::Dialog::AcceptLicense;
				
					my $dlg = SAPDB::Install::Dialog::AcceptLicense->new ($this,-1);
					
					unless ($dlg->ShowModal () == 0){
						$dlg->Destroy ();
						return undef;
					}
					$dlg->Destroy ();
				}
				$this->AddPendingEvent(Wx::CommandEvent->new(wxEVT_COMMAND_ENTER,98765))
			}
		],
		[
			"Show MaxDB\ncomponents",
			'icon/viewer.png',
			"Show existing\nMaxDB components\nand databases",
			sub {
				if($indep_data =~ /\S/ and -d "$indep_data/config/install"){
					require SAPDB::Install::Dialog::InstallationView;
					my $dlg = SAPDB::Install::Dialog::InstallationView->new($self,-1);
					$dlg->Destroy;
				}
				else{
					my $msgbox =  Wx::MessageDialog->new($self,'No installed MaxDB components found!',
					'Installation Viewer', wxICON_INFORMATION | wxCENTRE);
					$msgbox->ShowModal();
					$msgbox->Destroy;
				}
			}
		],
		[
			"Remove MaxDB\ncomponents",
			'icon/uninstall.png',
			"Uninstall already\ninstalled MaxDB\nsoftware and remove\nexisting databases",
			sub {
				
				unless(IsAdmin()){
					my $msgbox = Wx::MessageDialog->new($this,
									$^O =~ /mswin/i ? 
									'Please start installation as local administrator!' :
									'Please restart as user root!',
														"No Privileges", wxICON_ERROR | wxCENTRE);
					$msgbox->ShowModal();
					return;
				}
				
				if($indep_data =~ /\S/ and -d "$indep_data/config/install"){
					require SAPDB::Install::Dialog::Uninstall;
					my $dlg = SAPDB::Install::Dialog::Uninstall->new($self,-1);
					if (defined $dlg){
						$dlg->ShowModal;
						$dlg->Destroy;
						#
						#	reset cleaner
						#
						my $level = 0;
						while(1){
							my @all_info_caller_package = (caller($level));
							$#all_info_caller_package == -1  and last;
							$level++;
							my $package = $all_info_caller_package[0];
							if(defined ${"${package}::cleaner"} and	ref(${"${package}::cleaner"}) eq 'SAPDB::Install::Cleaner'){ 
								TraceMsg("found cleaner object \$${package}::cleaner\n",3,\$DEBUG);
								${"${package}::cleaner"}->DESTROY;
								last;
							}	
						}
					}	
				}
				else{
					my $msgbox =  Wx::MessageDialog->new($self,'No installed MaxDB components found!',
					'Installation Viewer', wxICON_INFORMATION | wxCENTRE);
					$msgbox->ShowModal();
					$msgbox->Destroy;
				}
			}
		],
		[
			"Visit MaxDB\nwebsite",
			'icon/globe.png',
			"Show MaxDB\nhomepage",
			sub {
				if($^O =~ /mswin/i){
					my $home_dir = $ENV{'HOMEDRIVE'}.$ENV{'HOMEPATH'};
					my $cwd;
					if(-d $home_dir){
						require SAPDB::Install::Cwd;
						$cwd = SAPDB::Install::Cwd::getcwd();	
						chdir($home_dir);
					}
					system("rundll32 url.dll,FileProtocolHandler http://www.sdn.sap.com/irj/sdn/maxdb");
					if($cwd =~ /\S/){
						chdir($cwd);
					}
				}
				else{
					my $browser = getBrowser();
					unless($browser =~ /\S/){
						my $msgbox =  Wx::MessageDialog->new($self,'Cannot detect a html browser',
						'Browser missing', wxICON_ERROR | wxCENTRE);
						$msgbox->ShowModal();
						$msgbox->Destroy;
						return undef;
					}
					system("$browser http://www.sdn.sap.com/irj/sdn/maxdb &");
				}			
			}
		]
	]);
	EVT_COMMAND_ENTER($this,98765,\&StartWizard);
	$this->{'browser'}->FindWindow($this->{'browser'}->{'links'}->[0])->select; 
	$sizer->Add($this->{'browser'},1,wxEXPAND);
	$this->SetSizerAndFit($sizer);
	$this->SetAutoLayout(1);
	
	#
	# use 3:2 ratio if possible
	#
	
	my ($w,$h) = $this->GetSizeWH;
	my $new_h = int($w * 2 / 3);
	if ($new_h > $h){
		$this->SetSize($w,$new_h);
	}
	
	$this->{'browser'}->SetFocus;
	$this;
}

sub StartWizard{
	my ($self,$evt) = @_;
	Wx::Yield();
	$self->GetSizer->Remove($self->{'browser'});
	$self->{'browser'}->Destroy;
	$self->{'browser'} = undef;
	delete $self->{'browser'};
	$self->{'wizard'} = SAPDB::Install::Window::Wizard->new($self,-1,[0,80],wxDefaultSize);
	
	
	if($SAPDB::Install::Config{'UsedSDBRUN'} eq 'installed'){
			require SAPDB::Install::Wizard::Dialog::ArchiveDir;
			$self->{'wizard'}->AddStep({'name' => 'Select MaxDB software package folder',
										'dlg' => SAPDB::Install::Wizard::Dialog::ArchiveDir->new($self->{'wizard'},
												-1,[0,0],wxDefaultSize)}
							);
	}
		
	$self->{'wizard'}->AddStep({'name' => 'Select component group to be installed',
								'dlg' => SAPDB::Install::Wizard::Dialog::Components->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	$self->{'wizard'}->AddStep({'name' => 'Checking installed software, please wait',
								'dlg' => SAPDB::Install::Wizard::Dialog::SoftwareParameter->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	$self->{'wizard'}->AddStep({'name' => 'Summary of installation settings',
								'dlg' => SAPDB::Install::Wizard::Dialog::Summary->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	
	$self->{'wizard'}->AddStep({'name' => 'Prepare software',
								'dlg' => SAPDB::Install::Wizard::Dialog::Prepare->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	$self->{'wizard'}->AddStep({'name' => 'Software installation',
								'dlg' => SAPDB::Install::Wizard::Dialog::Install->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
					);
	
	$self->{'wizard'}->AddStep({'name' => 'Finished',
								'dlg' => SAPDB::Install::Wizard::Dialog::Finalize->new($self->{'wizard'},-1,[0,0],wxDefaultSize)}
								);
	
	$self->GetSizer->Add($self->{'wizard'},1,wxEXPAND);
	$self->{'wizard'}->init;
	$self->{'wizard'}->SetFocus();
}


sub GetBestSize{
	my ($self) = @_;
	my ($width,$height) = (0,0);
	my $banner_size = $self->{'banner'}->GetBestSize;
	$height += $banner_size->GetHeight;
	$width = $banner_size->GetWidth;
	#print ">>>> banner size = ($width,$height)\n"; 
	
	if(defined $self->{'browser'}){
		my $browser_size = $self->{'browser'}->GetBestSize;
		$height += $browser_size->GetHeight;
		$width = $browser_size->GetWidth
			if $browser_size->GetWidth > $width;
	}
	elsif(defined $self->{'wizard'}){
		my $wizard_size = $self->{'wizard'}->GetBestSize;
		#print ">>>> wizard size (".$wizard_size->GetWidth.','.$wizard_size->GetHeight.")\n";
		$height += $wizard_size->GetHeight;
		$width = $wizard_size->GetWidth
			if $wizard_size->GetWidth > $width;
		$self->GetSizer->SetItemMinSize($self->{'wizard'},$wizard_size->GetWidth,$wizard_size->GetHeight);
	}
	return Wx::Size->new($width,$height);
}


sub RecalcBestSize{
	my ($self) = @_;
	$self->GetSizer->RecalcSizes;
	my $size = $self->GetBestSize;
	my ($width,$height) = ($size->GetWidth,$size->GetHeight);
	#print ">>>>> frame best size ($width,$height)\n";
	
	$self->SetSizeHints($width,$height); 
	my ($cur_width,$cur_height) = $self->GetSizeWH;
	my $dirty = 0;
	if($cur_width < $width){
		$cur_width = $width;
		$dirty = 1;	
	}
	if($cur_height < $height){
		$cur_height = $height;
		$dirty = 1;	
	}
	if($dirty){
		$self->SetSize([$cur_width,$cur_height]);
		$self->Layout;
	}
	$self->Layout;
	#print ">>>> frame real size (".join(',',$self->GetSizeWH).")\n";	
	
}


sub Destroy{
	my ($self) = @_;
	while($self->GetSizer->Remove(0)){}
	$self->{'banner'}->Destroy if defined $self->{'banner'};
	delete $self->{'banner'};
	$self->{'wizard'}->Destroy if defined $self->{'wizard'};
	delete $self->{'wizard'};
	$self->{'browser'}->Destroy if defined $self->{'browser'}; 
	delete $self->{'browser'};
	$self->SUPER::Destroy;
}


sub DESTROY{
	my ($self) = @_;
	print ">>>>>> DESTROYING $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;
}

1;
